// #autoload
// #name = HalLowAmmo
// #version = 1.6
// #date = April 9, 2002
// #author = Halide
// #warrior = Halide
// #email = halide@popmail.com
// #web = http://halides.tribes-universe.com/
// #description = Warns when you're low on ammo. Option to change weapons after you run out of ammo.
// #category = Halide's Scripts
// #include = support/key_callbacks.cs
// #include = support/callback.cs
// #include = support/loadout.cs
// #config = HalLowAmmoConfig

// If we haven't created the object "HalLowAmmo" then go ahead.
// Anything inside will be called when the script is first loaded.
if(!isObject(HalLowAmmo))
{
	new ScriptObject(HalLowAmmo)
	{
		class = HalLowAmmo;
		version = "1.6";
		// Warning sound for "low ammo"
		wavFile = "gui/objective_notification.wav";
		// Text colors, RGB format
		green = "50 250 50";
		orange = "250 175 0";
		red = "250 20 20";
	};
}

// START package HalLowAmmo
package HalLowAmmo
{

	// Set default prefs / load saved prefs
	function HalLowAmmo::setPrefs(%this)
	{
		// If the prefs file exists, and it's not already loaded, then load it...
		if(isFile("prefs/HalPrefs.cs") && !$HalPrefsLoaded)
		{
			exec("prefs/HalPrefs.cs");
			$HalPrefsLoaded = true;
		}

		if($HalPref::LowAmmo::Version $= "")
		{
			$HalPref::LowAmmo::Version = HalLowAmmo.version;
			$HalPref::LowAmmo::Enabled = true;
			$HalPref::LowAmmo::Percent = 0.15;
			$HalPref::LowAmmo::NextWep = true;
			$HalPref::LowAmmo::PreferredWep = false;
			$HalPref::LowAmmo::Sound = true;
			$HalPref::LowAmmo::WarningText = true;
			$HalPref::LowAmmo::ColorCoded = false;
			// Initialze the popup menus to "- None -"
			for(%i = 1; %i <= 10; %i++)
				$HalPref::LowAmmo::Menu[%i] = "- None -";
		}
	}

	// By overriding this function, we are getting the ammo count when the ammoHud is updated.
	// If we are "low" on ammo then activate the warning hud and/or sound.
	function ammoHud::setValue(%this, %val)
	{
		parent::setValue(%this, %val);

		// If disabled, then stop here
		if(!$HalPref::LowAmmo::Enabled)
			return;

		// Get the name of the weapon in hand
		%name = loadout.getCurrentWeapon();

		// If %val is empty, we have no weapon or it has infinite ammo
		if(%val $= "")
		{
			// Hide the warning text, and set the var that tells us it's hidden
			HalLowAmmoHud.setVisible(HalLowAmmo.hudOn = false);
			return;
		}

		// If the ammount of ammo we have qualifies as "low" then provide the appropriate warning text
		if(%val <= HalLowAmmo.lowAmmo[%name])
		{
			// Set colors according to the amount of ammo
			HalLowAmmoColorCoded.fontColor = %val == 0 ? HalLowAmmo.red : HalLowAmmo.orange;
			HalLowAmmoHud.setValue(%val == 0 ? "No Ammo" : "Low Ammo");
			// If no ammo, then let's check if the user wants to change weapons
			if(%val == 0)
				HalLowAmmo.checkChange();
			// Show the hud and/or play the sound
			HalLowAmmo.display(%name);
		}
		else
		{
			// Set green color for optimal ammo level
			HalLowAmmoColorCoded.fontColor = HalLowAmmo.green;
			// Hide the warning text, and set the var that tells us it's hidden
			HalLowAmmoHud.setVisible(HalLowAmmo.hudOn = false);
		}
	}

	// By overriding this function, we'll simply clear the warning text if we use the inventory station
	function clientCmdSetWeaponsHudClearAll()
	{
		parent::clientCmdSetWeaponsHudClearAll();

		HalLowAmmoHud.setVisible(false);
	}

	// By overriding this function, the warning text will be toggled on/off according to the ammoHud
	function ammoHud::setVisible(%this, %val)
	{
		parent::setVisible(%this, %val);

		// Check if the warning text is on, and toggle it on/off if needed
		if(HalLowAmmo.hudOn)
			HalLowAmmoHud.setVisible(%val);
	}

	// Changes your weapon when you're outta ammo.
	// Two methods: use next weapon or preferred.
	function HalLowAmmo::checkChange(%this)
	{
		// Next weapon...
		if($HalPref::LowAmmo::NextWep)
			nextWeapon(true);
		// Preferred weapon...
		else if($HalPref::LowAmmo::PreferredWep)
		{
			// Check if we have ammo for the preferred weapon's list. If we do, then switch to the first weapon that does.
			for(%i = 1; %i <= 10; %i++)
			{
				%name = HalLowAmmoConfig.Menu[%i].getValue();
				// If we have the weapon, and it has ammo...
				if(loadout.isLoadoutWeapon(%name) && loadout.getWeaponAmmo(%name))
				{
					// Switch weapons
					use(%name);
					return;
				}
			}
			// Fallback if we didn't find a new weapon
			nextWeapon(true);
		}
	}

	// Show the low ammo hud and/or play the warning sound
	function HalLowAmmo::display(%this, %name)
	{
		// If the user has sound enabled and it hasn't already been played
		if($HalPref::LowAmmo::Sound && !%this.soundPlayed[%name])
		{
			// Play the sound and remember that it has been played
			alxPlay(alxCreateSource(AudioChat, %this.wavFile));
			%this.soundPlayed[%name] = true;
		}
		// If the user has the warning text enabled...
		if($HalPref::LowAmmo::WarningText)
			// Show the hud and set the var that says so
			HalLowAmmoHud.setVisible((HalLowAmmo.hudOn = true) && ammoHud.visible);
		else
			// Hide the hud and set the var that says so
			HalLowAmmoHud.setVisible(HalLowAmmo.hudOn = false);
	}

	// This function is called whenever you access an inventory station or spawn.
	// It sets a var that expires within 1 second which will be used below to test if we have been given ammo.
	function HalLowAmmo::addAmmo(%this, %val)
	{
		// If argument is true...
		if(%val)
		{
			// Set the var that says we are getting ammo (from inv. station or spawn)
			%this.addAmmo = true;
			// Cancel any pending schedules
			cancel(%this.addAmmoSchedule);
			// Schedule to call this function with an argument of "0" in 1000ms (1 sec)
			%this.addAmmoSchedule = %this.schedule(1000, addAmmo, 0);
		}
		// If argument is false...
		else
			// Expire the var that says we are getting ammo
			%this.addAmmo = false;
	}

	// By overriding this function, we can find how much ammo we have for each weapon.
	// This is called often - everytime an ammo ammount for any weapon you are carrying changes.
	function clientCmdSetWeaponsHudAmmo(%slot, %ammoAmount)
	{
	   	parent::clientCmdSetWeaponsHudAmmo(%slot, %ammoAmount);

		// If we recently used an inventory station or spawned...
		if(%ammoAmount && HalLowAmmo.addAmmo)
		{
			// Calculate the "low" ammo amount for that weapon
			HalLowAmmo.lowAmmo[HalLowAmmo.nameBySlot[%slot]] = mCeil(%ammoAmount * $HalPref::LowAmmo::Percent);
			// Reset the var that says we played the warning sound for that weapon
			HalLowAmmo.soundPlayed[HalLowAmmo.nameBySlot[%slot]] = false;
		}
	}

	// By overriding this function, we can obtain a list of weapons from the server.
	// This lets the script be mod-compatible
	function clientCmdSetWeaponsHudBitmap(%slot, %name, %bitmap)
	{
		parent::clientCmdSetWeaponsHudBitmap(%slot, %name, %bitmap);

		// If this is the first time...
		if(!HalLowAmmo.addedWeapons)
		{
			for(%i = 1; %i <= 10; %i++)
			{
				// Activate the menu
				HalLowAmmoConfig.Menu[%i].setActive(true);
				// Clear the menu
				HalLowAmmoConfig.Menu[%i].clear();
				// Grab the pref and determine its slot
				%prefName = $HalPref::LowAmmo::Menu[%i];
				// If the pref is null set it to "- None -"
				%prefName = %prefName $= "" ? "- None -" : %prefName;
				// Set the pref on the popup menu
				HalLowAmmoConfig.Menu[%i].setValue(%prefName);
				// Add a default value
				HalLowAmmoConfig.Menu[%i].add("- None -", 0);
			}
			// Set the var that says we've done the first run through
			HalLowAmmo.addedWeapons = true;
			// Reset the total slots
			HalLowAmmo.totalSlots = 0;
		}

		// So we can find the name of a weapon by its slot number...
		HalLowAmmo.nameBySlot[%slot] = %name;
		// Increment the total slots counter
		HalLowAmmo.totalSlots++;
		// Add the weapon to all the menus
		for(%i = 1; %i <= 10; %i++)
			HalLowAmmoConfig.Menu[%i].add($WeaponNames[HalLowAmmo.totalSlots - 1], HalLowAmmo.totalSlots);
	}

	// This function will setup everything needed at startup.
	// Callbacks, GUIs, and the sound profile
	function HalLowAmmo::setup(%this)
	{
		// If this has been done already, then stop here
		if(%this.setup)
			return;

		// Set default prefs / load saved prefs
		%this.setPrefs();

		// Add callbacks when play uses an invtentory station or spawns.
		// This will help in calculating "low" ammo values
		Callback.add("PlayerUseInv", "HalLowAmmo.addAmmo(true);");
		Callback.add("PlayerSpawn", "HalLowAmmo.addAmmo(true);");

		// Create text profiles for the Green, Orange, and Red text on the options gui
		new GuiControlProfile(HalLowAmmoGreen)
		{
			fontType = "Univers Condensed";
			fontSize = 16;
			fontColor = HalLowAmmo.green;
			justify = "left";
		};
		new GuiControlProfile(HalLowAmmoOrange)
		{
			fontType = "Univers Condensed";
			fontSize = 16;
			fontColor = HalLowAmmo.orange;
			justify = "left";
		};
		new GuiControlProfile(HalLowAmmoRed)
		{
			fontType = "Univers Condensed";
			fontSize = 16;
			fontColor = HalLowAmmo.red;
			justify = "left";
		};

		// Create the color coded text profile
		new GuiControlProfile(HalLowAmmoColorCoded)
		{
			fontType = "Univers Condensed";
			fontSize = 16;
			fontColor = "";
			justify = "left";
		};

		// Warning hud/text
		new GuiTextCtrl(HalLowAmmoHud)
		{
			profile = "HalLowAmmoColorCoded";
			horizSizing = "left";
			vertSizing = "top";
			extent = "80 20";
			minExtent = "8 8";
			visible = "0";
			hideCursor = "0";
			bypassHideCursor = "0";
			helpTag = "0";
			longTextBuffer = "0";
			maxLength = "255";
		};

		// Add the hud to the same parent as the ammoHud, so that we can set its position more easily
		retCenterHud.add(HalLowAmmoHud);

		// Set its position right under the ammoHud (near your reticle)
		HalLowAmmoHud.position = getWord(ammoHud.position,0) SPC (getWord(ammoHud.position,1) + 16);

		// Create the huge options gui ;)
		new GuiControl(HalLowAmmoConfig) {
			profile = "GuiDefaultProfile";
			horizSizing = "center";
			vertSizing = "center";
			position = "0 0";
			extent = "640 480";
			minExtent = "8 8";
			visible = "1";
			hideCursor = "0";
			bypassHideCursor = "0";
			helpTag = "0";

			new ShellPaneCtrl(HalLowAmmoConfigPane) {
				profile = "ShellPaneProfile";
				horizSizing = "center";
				vertSizing = "center";
				position = "157 80";
				extent = "325 317";
				minExtent = "48 92";
				visible = "1";
				hideCursor = "0";
				bypassHideCursor = "0";
				helpTag = "0";
				text = "HalLowAmmo";
				longTextBuffer = "0";
				maxLength = "255";
				noTitleBar = "0";

				new ShellFieldCtrl() {
					profile = "ShellFieldProfile";
					horizSizing = "right";
					vertSizing = "bottom";
					position = "19 226";
					extent = "287 71";
					minExtent = "16 18";
					visible = "1";
					hideCursor = "0";
					bypassHideCursor = "0";
					helpTag = "0";
				};
				new ShellFieldCtrl() {
					profile = "ShellFieldProfile";
					horizSizing = "right";
					vertSizing = "bottom";
					position = "19 29";
					extent = "287 195";
					minExtent = "16 18";
					visible = "1";
					hideCursor = "0";
					bypassHideCursor = "0";
					helpTag = "0";
				};
				new ShellToggleButton(HalLowAmmoConfigPreferredWep) {
					profile = "ShellRadioProfile";
					horizSizing = "right";
					vertSizing = "bottom";
					position = "48 52";
					extent = "228 27";
					minExtent = "26 27";
					visible = "1";
					hideCursor = "0";
					bypassHideCursor = "0";
					variable = "$HalPref::LowAmmo::PreferredWep";
					helpTag = "0";
					text = "Use preferred weapon when out of ammo";
					longTextBuffer = "0";
					maxLength = "255";
				};
				new GuiTextCtrl() {
					profile = "ShellTextProfile";
					horizSizing = "right";
					vertSizing = "bottom";
					position = "30 95";
					extent = "13 22";
					minExtent = "8 8";
					visible = "1";
					hideCursor = "0";
					bypassHideCursor = "0";
					helpTag = "0";
					text = "1 -";
					longTextBuffer = "0";
					maxLength = "255";
				};
				new GuiTextCtrl() {
					profile = "ShellTextProfile";
					horizSizing = "right";
					vertSizing = "bottom";
					position = "30 121";
					extent = "13 22";
					minExtent = "8 8";
					visible = "1";
					hideCursor = "0";
					bypassHideCursor = "0";
					helpTag = "0";
					text = "2 -";
					longTextBuffer = "0";
					maxLength = "255";
				};
				new GuiTextCtrl() {
					profile = "ShellTextProfile";
					horizSizing = "right";
					vertSizing = "bottom";
					position = "30 147";
					extent = "13 22";
					minExtent = "8 8";
					visible = "1";
					hideCursor = "0";
					bypassHideCursor = "0";
					helpTag = "0";
					text = "3 -";
					longTextBuffer = "0";
					maxLength = "255";
				};
				new GuiTextCtrl() {
					profile = "ShellTextProfile";
					horizSizing = "right";
					vertSizing = "bottom";
					position = "30 173";
					extent = "13 22";
					minExtent = "8 8";
					visible = "1";
					hideCursor = "0";
					bypassHideCursor = "0";
					helpTag = "0";
					text = "4 -";
					longTextBuffer = "0";
					maxLength = "255";
				};
				new GuiTextCtrl() {
					profile = "ShellTextProfile";
					horizSizing = "right";
					vertSizing = "bottom";
					position = "30 199";
					extent = "13 22";
					minExtent = "8 8";
					visible = "1";
					hideCursor = "0";
					bypassHideCursor = "0";
					helpTag = "0";
					text = "5 -";
					longTextBuffer = "0";
					maxLength = "255";
				};
				new ShellToggleButton(HalLowAmmoConfigWarningText) {
					profile = "ShellRadioProfile";
					horizSizing = "right";
					vertSizing = "bottom";
					position = "28 248";
					extent = "130 30";
					minExtent = "26 27";
					visible = "1";
					hideCursor = "0";
					bypassHideCursor = "0";
					variable = "$HalPref::LowAmmo::WarningText";
					helpTag = "0";
					text = "Warning text";
					longTextBuffer = "0";
					maxLength = "255";
				};
				new ShellToggleButton(HalLowAmmoConfigColorCoded) {
					profile = "ShellRadioProfile";
					horizSizing = "right";
					vertSizing = "bottom";
					position = "28 269";
					extent = "130 27";
					minExtent = "26 27";
					visible = "1";
					hideCursor = "0";
					bypassHideCursor = "0";
					variable = "$HalPref::LowAmmo::ColorCoded";
					helpTag = "0";
					text = "Color-coded ammo #";
					longTextBuffer = "0";
					maxLength = "255";
				};
				new ShellToggleButton(HalLowAmmoConfigNextWep) {
					profile = "ShellRadioProfile";
					horizSizing = "right";
					vertSizing = "bottom";
					position = "48 31";
					extent = "228 27";
					minExtent = "26 27";
					visible = "1";
					hideCursor = "0";
					bypassHideCursor = "0";
					variable = "$HalPref::LowAmmo::NextWep";
					helpTag = "0";
					text = "Use next weapon when out of ammo";
					longTextBuffer = "0";
					maxLength = "255";
				};
				new GuiTextCtrl() {
					profile = "GuiDefaultProfile";
					horizSizing = "right";
					vertSizing = "bottom";
					position = "44 77";
					extent = "244 21";
					minExtent = "8 8";
					visible = "1";
					hideCursor = "0";
					bypassHideCursor = "0";
					helpTag = "0";
					text = "You must join a server to set preferred weapons!";
					longTextBuffer = "0";
					maxLength = "255";
				};
				new GuiTextCtrl(HalLowAmmoConfigPercentText) {
					profile = "ShellTextProfile";
					horizSizing = "right";
					vertSizing = "bottom";
					position = "183 232";
					extent = "88 22";
					minExtent = "8 8";
					visible = "1";
					hideCursor = "0";
					bypassHideCursor = "0";
					helpTag = "0";
					text = "Low Ammo (xx%)";
					longTextBuffer = "0";
					maxLength = "255";
				};
				new ShellSliderCtrl(HalLowAmmoConfigPercentSlider) {
					profile = "ShellSliderProfile";
					horizSizing = "right";
					vertSizing = "bottom";
					position = "166 247";
					extent = "124 24";
					minExtent = "12 24";
					visible = "1";
					hideCursor = "0";
					bypassHideCursor = "0";
					altCommand = "HalLowAmmo.updatePercent();";
					helpTag = "0";
					range = "0.100000 0.500000";
					ticks = "1000";
					value = "0.15";
					usePlusMinus = "1";
				};
				new ShellToggleButton(HalLowAmmoConfigSound) {
					profile = "ShellRadioProfile";
					horizSizing = "right";
					vertSizing = "bottom";
					position = "28 227";
					extent = "130 30";
					minExtent = "26 27";
					visible = "1";
					hideCursor = "0";
					bypassHideCursor = "0";
					variable = "$HalPref::LowAmmo::Sound";
					helpTag = "0";
					text = "Warning sound";
					longTextBuffer = "0";
					maxLength = "255";
				};
				new GuiTextCtrl() {
					profile = "ShellTextProfile";
					horizSizing = "right";
					vertSizing = "bottom";
					position = "170 95";
					extent = "13 22";
					minExtent = "8 8";
					visible = "1";
					hideCursor = "0";
					bypassHideCursor = "0";
					helpTag = "0";
					text = "6 -";
					longTextBuffer = "0";
					maxLength = "255";
				};
				new GuiTextCtrl() {
					profile = "ShellTextProfile";
					horizSizing = "right";
					vertSizing = "bottom";
					position = "170 121";
					extent = "13 22";
					minExtent = "8 8";
					visible = "1";
					hideCursor = "0";
					bypassHideCursor = "0";
					helpTag = "0";
					text = "7 -";
					longTextBuffer = "0";
					maxLength = "255";
				};
				new GuiTextCtrl() {
					profile = "ShellTextProfile";
					horizSizing = "right";
					vertSizing = "bottom";
					position = "170 147";
					extent = "13 22";
					minExtent = "8 8";
					visible = "1";
					hideCursor = "0";
					bypassHideCursor = "0";
					helpTag = "0";
					text = "8 -";
					longTextBuffer = "0";
					maxLength = "255";
				};
				new GuiTextCtrl() {
					profile = "ShellTextProfile";
					horizSizing = "right";
					vertSizing = "bottom";
					position = "170 173";
					extent = "13 22";
					minExtent = "8 8";
					visible = "1";
					hideCursor = "0";
					bypassHideCursor = "0";
					helpTag = "0";
					text = "9 -";
					longTextBuffer = "0";
					maxLength = "255";
				};
				new GuiTextCtrl() {
					profile = "ShellTextProfile";
					horizSizing = "right";
					vertSizing = "bottom";
					position = "163 199";
					extent = "20 22";
					minExtent = "8 8";
					visible = "1";
					hideCursor = "0";
					bypassHideCursor = "0";
					helpTag = "0";
					text = "10 -";
					longTextBuffer = "0";
					maxLength = "255";
				};
				new GuiTextCtrl() {
					profile = "HalLowAmmoRed";
					horizSizing = "right";
					vertSizing = "bottom";
					position = "251 273";
					extent = "24 22";
					minExtent = "8 8";
					visible = "1";
					hideCursor = "0";
					bypassHideCursor = "0";
					helpTag = "0";
					text = "Red";
					longTextBuffer = "0";
					maxLength = "255";
				};
				new GuiTextCtrl() {
					profile = "HalLowAmmoOrange";
					horizSizing = "right";
					vertSizing = "bottom";
					position = "217 273";
					extent = "34 22";
					minExtent = "8 8";
					visible = "1";
					hideCursor = "0";
					bypassHideCursor = "0";
					helpTag = "0";
					text = "Orange";
					longTextBuffer = "0";
					maxLength = "255";
				};
				new GuiTextCtrl() {
					profile = "HalLowAmmoGreen";
					horizSizing = "right";
					vertSizing = "bottom";
					position = "188 273";
					extent = "34 22";
					minExtent = "8 8";
					visible = "1";
					hideCursor = "0";
					bypassHideCursor = "0";
					helpTag = "0";
					text = "Green";
					longTextBuffer = "0";
					maxLength = "255";
				};
			};
		};

		HalLowAmmoConfig.Menu[1] = new ShellPopupMenu() {
			profile = "ShellPopupProfile";
			horizSizing = "right";
			vertSizing = "bottom";
			position = "38 87";
			extent = "130 36";
			minExtent = "49 36";
			visible = "1";
			hideCursor = "0";
			bypassHideCursor = "0";
			helpTag = "0";
			text = "- None -";
			longTextBuffer = "0";
			maxLength = "255";
			maxPopupHeight = "200";
			buttonBitmap = "gui/shll_pulldown";
			rolloverBarBitmap = "gui/shll_pulldownbar_rol";
			selectedBarBitmap = "gui/shll_pulldownbar_act";
			noButtonStyle = "0";
		};

		HalLowAmmoConfig.Menu[2] = new ShellPopupMenu() {
			profile = "ShellPopupProfile";
			horizSizing = "right";
			vertSizing = "bottom";
			position = "38 113";
			extent = "130 36";
			minExtent = "49 36";
			visible = "1";
			hideCursor = "0";
			bypassHideCursor = "0";
			helpTag = "0";
			text = "- None -";
			longTextBuffer = "0";
			maxLength = "255";
			maxPopupHeight = "200";
			buttonBitmap = "gui/shll_pulldown";
			rolloverBarBitmap = "gui/shll_pulldownbar_rol";
			selectedBarBitmap = "gui/shll_pulldownbar_act";
			noButtonStyle = "0";
		};

		HalLowAmmoConfig.Menu[3] = new ShellPopupMenu() {
			profile = "ShellPopupProfile";
			horizSizing = "right";
			vertSizing = "bottom";
			position = "38 139";
			extent = "130 36";
			minExtent = "49 36";
			visible = "1";
			hideCursor = "0";
			bypassHideCursor = "0";
			helpTag = "0";
			text = "- None -";
			longTextBuffer = "0";
			maxLength = "255";
			maxPopupHeight = "200";
			buttonBitmap = "gui/shll_pulldown";
			rolloverBarBitmap = "gui/shll_pulldownbar_rol";
			selectedBarBitmap = "gui/shll_pulldownbar_act";
			noButtonStyle = "0";
		};

		HalLowAmmoConfig.Menu[4] = new ShellPopupMenu() {
			profile = "ShellPopupProfile";
			horizSizing = "right";
			vertSizing = "bottom";
			position = "38 165";
			extent = "130 36";
			minExtent = "49 36";
			visible = "1";
			hideCursor = "0";
			bypassHideCursor = "0";
			helpTag = "0";
			text = "- None -";
			longTextBuffer = "0";
			maxLength = "255";
			maxPopupHeight = "200";
			buttonBitmap = "gui/shll_pulldown";
			rolloverBarBitmap = "gui/shll_pulldownbar_rol";
			selectedBarBitmap = "gui/shll_pulldownbar_act";
			noButtonStyle = "0";
		};

		HalLowAmmoConfig.Menu[5] = new ShellPopupMenu() {
			profile = "ShellPopupProfile";
			horizSizing = "right";
			vertSizing = "bottom";
			position = "38 191";
			extent = "130 36";
			minExtent = "49 36";
			visible = "1";
			hideCursor = "0";
			bypassHideCursor = "0";
			helpTag = "0";
			text = "- None -";
			longTextBuffer = "0";
			maxLength = "255";
			maxPopupHeight = "200";
			buttonBitmap = "gui/shll_pulldown";
			rolloverBarBitmap = "gui/shll_pulldownbar_rol";
			selectedBarBitmap = "gui/shll_pulldownbar_act";
			noButtonStyle = "0";
		};

		HalLowAmmoConfig.Menu[6] = new ShellPopupMenu() {
			profile = "ShellPopupProfile";
			horizSizing = "right";
			vertSizing = "bottom";
			position = "177 87";
			extent = "130 36";
			minExtent = "49 36";
			visible = "1";
			hideCursor = "0";
			bypassHideCursor = "0";
			helpTag = "0";
			text = "- None -";
			longTextBuffer = "0";
			maxLength = "255";
			maxPopupHeight = "200";
			buttonBitmap = "gui/shll_pulldown";
			rolloverBarBitmap = "gui/shll_pulldownbar_rol";
			selectedBarBitmap = "gui/shll_pulldownbar_act";
			noButtonStyle = "0";
		};

		HalLowAmmoConfig.Menu[7] = new ShellPopupMenu() {
			profile = "ShellPopupProfile";
			horizSizing = "right";
			vertSizing = "bottom";
			position = "177 113";
			extent = "130 36";
			minExtent = "49 36";
			visible = "1";
			hideCursor = "0";
			bypassHideCursor = "0";
			helpTag = "0";
			text = "- None -";
			longTextBuffer = "0";
			maxLength = "255";
			maxPopupHeight = "200";
			buttonBitmap = "gui/shll_pulldown";
			rolloverBarBitmap = "gui/shll_pulldownbar_rol";
			selectedBarBitmap = "gui/shll_pulldownbar_act";
			noButtonStyle = "0";
		};

		HalLowAmmoConfig.Menu[8] = new ShellPopupMenu() {
			profile = "ShellPopupProfile";
			horizSizing = "right";
			vertSizing = "bottom";
			position = "177 139";
			extent = "130 36";
			minExtent = "49 36";
			visible = "1";
			hideCursor = "0";
			bypassHideCursor = "0";
			helpTag = "0";
			text = "- None -";
			longTextBuffer = "0";
			maxLength = "255";
			maxPopupHeight = "200";
			buttonBitmap = "gui/shll_pulldown";
			rolloverBarBitmap = "gui/shll_pulldownbar_rol";
			selectedBarBitmap = "gui/shll_pulldownbar_act";
			noButtonStyle = "0";
		};

		HalLowAmmoConfig.Menu[9] = new ShellPopupMenu() {
			profile = "ShellPopupProfile";
			horizSizing = "right";
			vertSizing = "bottom";
			position = "177 165";
			extent = "130 36";
			minExtent = "49 36";
			visible = "1";
			hideCursor = "0";
			bypassHideCursor = "0";
			helpTag = "0";
			text = "- None -";
			longTextBuffer = "0";
			maxLength = "255";
			maxPopupHeight = "200";
			buttonBitmap = "gui/shll_pulldown";
			rolloverBarBitmap = "gui/shll_pulldownbar_rol";
			selectedBarBitmap = "gui/shll_pulldownbar_act";
			noButtonStyle = "0";
		};

		HalLowAmmoConfig.Menu[10] = new ShellPopupMenu() {
			profile = "ShellPopupProfile";
			horizSizing = "right";
			vertSizing = "bottom";
			position = "177 191";
			extent = "130 36";
			minExtent = "49 36";
			visible = "1";
			hideCursor = "0";
			bypassHideCursor = "0";
			helpTag = "0";
			text = "- None -";
			longTextBuffer = "0";
			maxLength = "255";
			maxPopupHeight = "200";
			buttonBitmap = "gui/shll_pulldown";
			rolloverBarBitmap = "gui/shll_pulldownbar_rol";
			selectedBarBitmap = "gui/shll_pulldownbar_act";
			noButtonStyle = "0";
		};
		// End of options gui

		// Set the var that says we haven't added weapons
		%this.addedWeapons = false;

		// Loop through the popup menus...
		for(%i = 1; %i <= 10; %i++)
		{
			// Add them to the gui pane
			HalLowAmmoConfigPane.add(HalLowAmmoConfig.Menu[%i]);
			// Deactivate them since we haven't filled them with the weapons list
			HalLowAmmoConfig.Menu[%i].setActive(false);
			// Add an undecided selection
			HalLowAmmoConfig.Menu[%i].add("- None -", 0);
			// Set the pref for the popup menu text
			HalLowAmmoConfig.Menu[%i].setValue($HalPref::LowAmmo::Menu[%i]);
		}

		// Set the pref values on the options gui...
		HalLowAmmoConfigNextWep.setValue($HalPref::LowAmmo::NextWep);
		HalLowAmmoConfigPreferredWep.setValue($HalPref::LowAmmo::PreferredWep);
		HalLowAmmoConfigSound.setValue($HalPref::LowAmmo::Sound);
		HalLowAmmoConfigWarningText.setValue($HalPref::LowAmmo::WarningText);
		HalLowAmmoConfigColorCoded.setValue($HalPref::LowAmmo::ColorCoded);
		HalLowAmmoConfigPercentSlider.setValue($HalPref::LowAmmo::Percent);

		// If using color coded ammo #, change the ammoHud's profile
		if($HalPref::LowAmmo::ColorCoded)
			ammoHud.setProfile("HalLowAmmoColorCoded");

		// Set the var that says we've done setup
		%this.setup = true;
	}

	function HalLowAmmoConfig::onWake(%this)
	{
		// nothing
	}

	// Updates the % text when the slider is being scrolled, and sets the pref
	function HalLowAmmo::updatePercent(%this)
	{
		HalLowAmmoConfigPercentText.setValue("Low Ammo (" @ mFloor(HalLowAmmoConfigPercentSlider.getValue() * 100) @ "%)");
		$HalPref::LowAmmo::Percent = HalLowAmmoConfigPercentSlider.getValue();
	}

	// Toggle the color coded text if the user changes the pref through the options gui
	function HalLowAmmoConfigColorCoded::onAction(%this)
	{
		if(%this.getValue())
			ammoHud.setProfile("HalLowAmmoColorCoded");
		else
			ammoHud.setProfile("GuiAmmoHudProfile");
	}

	// Toggle the warning text if the user changes the pref through the options gui
	function HalLowAmmoConfigWarningText::onAction(%this)
	{
		HalLowAmmoHud.setVisible(HalLowAmmo.hudOn && %this.getValue());
	}

	// Keeps "next" and "preferred" buttons from both being enabled
	function HalLowAmmoConfigNextWep::onAction(%this)
	{
		if(%this.getValue())
			HalLowAmmoConfigPreferredWep.setValue(false);
	}

	// Keeps "next" and "preferred" buttons from both being enabled
	function HalLowAmmoConfigPreferredWep::onAction(%this)
	{
		if(%this.getValue())
			HalLowAmmoConfigNextWep.setValue(false);
	}

	// This function is called whenever the toggle key is depressed or released
	function HalLowAmmoToggle(%val)
	{
		// If depressed...
		if(%val)
		{
			// Toggle the enabled pref
			$HalPref::LowAmmo::Enabled = !$HalPref::LowAmmo::Enabled;

			// Play a beep
			alxPlay(sButtonOver, 0, 0, 0);

			// If enabled...
			if($HalPref::LowAmmo::Enabled)
			{
				// Set the correct color-coded ammo # if needed
				if($HalPref::LowAmmo::ColorCoded)
					ammoHud.setProfile("HalLowAmmoColorCoded");
				// Show the warning text if it was on
				HalLowAmmoHud.setVisible(HalLowAmmo.hudOn);
				// Add message to the chat hud that is has been enabled
				addMessageHudLine("\c2HalLowAmmo enabled.");
			}
			// If disabled...
			else
			{
				// Change to the default ammo hud profile
				ammoHud.setProfile("GuiAmmoHudProfile");
				// Hide the warning text if it's here
				HalLowAmmoHud.setVisible(false);
				// Add message to the chat hud that it has been disabled
				addMessageHudLine("\c2HalLowAmmo disabled.");
			}
		}
	}

	// By overriding this function, we'll add the toggle key to the controls list
	function OptionsDlg::onWake(%this)
	{
		// If we haven't added it already...
		if(!$HalLowAmmoBind)
		{
			// Add the main toggle and increment the controls list count
			$RemapName[$RemapCount]="HalLowAmmo Toggle";
			$RemapCmd[$RemapCount]="HalLowAmmoToggle";
			$RemapCount++;
			// Signify that we've added the items to the controls list
			$HalLowAmmoBind = true;
		}

		parent::onWake(%this);
	}

	// By overriding this function, we will deactivate the popup menus on the options gui, and set the prefs to their values
	function disconnect()
	{
		// Loop through the popup menus...
		for(%i = 1; %i <= 10; %i++)
		{
			// Set the pref from the popup menu
			$HalPref::LowAmmo::Menu[%i] = HalLowAmmoConfig.Menu[%i].getValue();
			// Deactive the popup menu
			HalLowAmmoConfig.Menu[%i].setActive(false);
		}

		// Reset the var that says we've added the weapons from this mod to the popup menus
		HalLowAmmo.addedWeapons = false;

		parent::disconnect();
	}

	// By overriding this function, we save the prefs to a file on exit
	function quit()
	{
		// If not saved already (can be done from another script)
		if(!$HalPrefsSaved)
		{
			// Save the prefs to a file
			export("$HalPref::*", "prefs/HalPrefs.cs", false);
			// Set the pref that says so
			$HalPrefsSaved = true;
		}

		parent::quit();
	}

// END package HalLowAmmo
};
activatePackage(HalLowAmmo);

// Setup everything!
HalLowAmmo.setup();